@@ -49,8 +49,8 @@ class SparkPipelineFrameworkTestRunner:
         apply_schema_to_output: bool = True,
         check_output: bool = True,
         ignore_views_for_output: Optional[List[str]] = None,
-        input_schema: Optional[Union[StructType, Dict[str, StructType]]] = None,
-        output_schema: Optional[Union[StructType, Dict[str, StructType]]] = None,
+        input_schema: Optional[Union[StructType, Dict[str, StructType], DataType]] = None,
+        output_schema: Optional[Union[StructType, Dict[str, StructType], DataType]] = None,
     ) -> None:
         """
         Tests Spark Transformers without writing any code
@@ -315,7 +315,7 @@ class SparkPipelineFrameworkTestRunner:
         func_path_modifier: Optional[Callable[[Union[Path, str]], Union[Path, str]]],
         sort_output_by: Optional[List[str]],
         apply_schema_to_output: bool,
-        output_schema: Optional[Union[StructType, Dict[str, StructType]]],
+        output_schema: Optional[Union[StructType, Dict[str, StructType], DataType]],
         temp_folder: Optional[Union[Path, str]] = None,
     ) -> Tuple[bool, Optional[SparkDataFrameComparerException]]:
         data_frame_exception: Optional[SparkDataFrameComparerException] = None
@@ -505,7 +505,7 @@ class SparkPipelineFrameworkTestRunner:
         input_file: str,
         input_folder: Path,
         input_schema_folder: Path,
-        input_schema: Optional[Union[StructType, Dict[str, StructType]]],
+        input_schema: Optional[Union[StructType, Dict[str, StructType], DataType]],
     ) -> None:
         file_extension: str = (
             SparkPipelineFrameworkTestRunner.get_file_extension_from_file_path(
